<?xml version="1.0" ?><!DOCTYPE TS><TS language="nb" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Det finnes et liv utenfor nettleseren!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versjon %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Lisensiert til: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 er fri programvare, men utviklingen tar dyrbar tid.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Vennligst &lt;a href=&apos;%1&apos;&gt;donér&lt;/a&gt; for å støtte videre utvikling av %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Oversett %1 til ditt morsmål ved hjelp av %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikonet er designet av %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Utgitt under &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Skriv inn lisensdetaljer</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-post:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kode:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Vennligst lisensier %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Demoen er utløpt.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Den fulle versjonen tillater deg å se videoer uten avbrudd.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Uten lisens, vil programmet utløpe om %1 dager.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ved å kjøpe fullversjonen, støtter du det harde arbeidet som ble lagt inn i å skape %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Bruk demoen</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Angi Lisens</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Kjøp Lisens</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Ved %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Alle Videoer</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Usette Videoer</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Sist Oppdatert</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Sist Lagt Til</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Sist Sett</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Mest Sett</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sorter etter</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marker alle som sett</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Program Oppdatert</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Du har ingen abonnement. Bruk stjernesymbolet for å abonnemere på kanaler.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Alle Videoer</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Usette Videoer</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marker som Sett</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Avslutte Abonnement</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Det er ingen oppdaterte abonnement for øyeblikket</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Akkurat nå</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 visninger</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/sek</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sek</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sek</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 gjenstår</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 nedlastet på %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Nedlastingen ferdig</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Endre sted ...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Velg nedlastingsmappe</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Nedlastingsmappe endret.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Pågående nedlastinger vil bli lagret i den forrige mappen.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Laster ned til: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Nedlastinger</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Den kjørbare filen er infisert, muligens med et virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 vil ikke kjøre. Prøv å installere igjen.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Installer på nytt</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Spill av</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Spill av/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stopp avspilling etter denne videoen.</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Neste video</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Forrige video</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Øk lydvolumet</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Senk lydvolumet</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Lydløs</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Søk forover</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Søk bakover</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Finn videoer og kanaler med søkeord</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bla gjennom</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Bla gjennom videoer etter kategori</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonnement</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanalabonnementer</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Gjør deg komfortabel</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Vindu</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimer</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stopp avspilling og gå tilbake til søkevisningen</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Forrige</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Gå til forrige spor</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hopp over</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Hopp til neste video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spill av</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Gjenoppta avspilling</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Fullskjermsvisning</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompakt modus</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Gjem spillelista og verktøylinja</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Åpne siden på &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gå til YouTube video siden og pause avspillingen</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopier &amp;lenken til YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopier denne YouTube video linken til utklippstavle</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopier &amp;URL-en til videostrømmen</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopier denne video stream URL til utklippstavle</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Finn &amp;deler av videoen</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Finn andre videosegment, forhåpentligvis i rett rekkefølge</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Fjern valgte videoer fra spillelista</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flytt &amp;opp</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Flytt opp valgte videoer i spillelista</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flytt &amp;Ned</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Flytt ned valgte videoer i spillelista</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>T&amp;øm siste søk</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Fjern all søkehistorie. Kan ikke angres.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Farvel</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettsted</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 på internett</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Gi en &amp;donasjon</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Vi håper du kan bidra til å fortsette arbeidet med utvikling av %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informasjon om %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Lydløs</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Start avspillingen &amp;manuelt</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Spill av videoer manuelt</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Nedlastinger</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Vis detaljer om nedlasting av video</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Nedlasting</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Last ned denne videoen</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Ta &amp;Skjermdump</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Abonner på Kanal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Del denne videoen med %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-post</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-post</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Steng</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Vis over andre</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Stopp etter denne videoen</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Rapporter et Problem</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Detaljert søk...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Mer...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Relaterte Videoer</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Se videoer relatert til den nåværende</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Åpne i &amp;Nettleser</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Begrenset Modus</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Skjul videoer som kan inneholde upassende innhold</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Liker du %1? Ranger den!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Kjøp %1 …</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Applikasjon</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Avspilling</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Spilleliste</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Del</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visning</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Trykk på %1 for å øke lydvolumet, %2 for å senke</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Velg innholdsplassering</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Åpner %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Vil du avslutte %1 mens nedlastinger pågår?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Hvis du stenger %1 nå, vil nedlastingen bli avbrutt</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Steng og avbryt nedlastingen </translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Vent mens nedlastingen fullføres</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Feil: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Sett avspilling på pause</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Laster...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Forlat &amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Gjenstående tid: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Lydløst er på</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Lydløst er av</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimal videodefinisjon satt til %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Ditt personvern er nå sikkert</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Nedlastinger fullført</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>Versjon %2 av %1 er nå tilgjengelig.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Minn meg på det senere</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Oppdater</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Du kan nå lime inn YouTube linken i et annet program</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Du kan nå lime inn video stream URL i en annen applikasjon</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Denne linken vil kun være gyldig i en begrenset tid.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Nedlasting %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>av</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>del</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episode</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Sent fra %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Meld deg ut fra %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Abonnér på %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Du er utmeldt fra %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Abonnert på %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>En ny versjon av %1 er tilgjengelig!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 er nå tilgjengelig. Du har %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Vil du last den ned nå?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Hopp Over Denne Versjonen</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Minn meg på det senere</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Installer Oppdatering</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 av %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Forbereder</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislykket</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Fullført</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Stoppet</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Stopp nedlastingen</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Vis i %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Åpen den overordnede mappen</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Start nedlastning på nytt</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Vis %1 Mer</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ingen videoer</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ingen flere videoer</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sorter etter</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevanse</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Antall ganger sett</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Vurdering</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Når som helst</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>I dag</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Dager</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Dager</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Varighet</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Lange</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Mindre enn 4 minutter</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Mellom 4 og 20 minutter</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Lengre enn 20 minutter</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Høy Definisjon</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p eller høyere</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Ferdig</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Ferdig</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Velkommen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>for å begynne avspilling av video</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>ett nøkkelord</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Skriv</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Nylige søkeord</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Nylige kanaler</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Kjøp fullversjon</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Tilbake</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Fremover til %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Tilbake til %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Detaljert søk</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Mente du: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Endre sted ...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Skjermdump lagret på %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Plassering av øyeblikksbilder er endret.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Mest Populære</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Laster ned oppdatering...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Laster ned %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algerie</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgia</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Den Tsjekkiske Republikk</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Frankrike</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Tyskland</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Hellas</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ungarn</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordan</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexico</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marokko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nederland</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>New Zealand</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filippinene</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Russland</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudi Arabia</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sør Africa</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Sør Korea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spania</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Sverige</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Tyrkia</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>De Forente Arabiske Emirater</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Storbritannia</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Over hele verden</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan ikke hente mediastrøm for %1</translation>
    </message>
</context>
</TS>